==> reakit-system-bootstrap-0.4.1.tgz: package/es/Tooltip.js <==
import { c as _objectWithoutPropertiesLoose, a as _objectSpread, b as _taggedTemplateLiteralLoose } from './chunk-119337e1.js';
import { css, cx } from 'emotion';
import { useBoxProps } from 'reakit-system-palette/Box';
import { useFade } from 'reakit-system-palette/utils/fade';

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n    background-color: ", ";\n    font-size: 0.8em;\n    padding: 0.5rem;\n    border-radius: 0.25rem;\n\n    & > .arrow {\n      background-color: transparent;\n      font-size: 1.25em !important;\n      & .stroke {\n        fill: transparent;\n      }\n      & .fill {\n        fill: ", ";\n      }\n    }\n  "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
function useTooltipOptions(_ref) {
  var _ref$unstable_system = _ref.unstable_system;
  _ref$unstable_system = _ref$unstable_system === void 0 ? {} : _ref$unstable_system;

  var _ref$unstable_system$ = _ref$unstable_system.palette,
      palette = _ref$unstable_system$ === void 0 ? "foreground" : _ref$unstable_system$,
      _ref$unstable_system$2 = _ref$unstable_system.fill,
      fill = _ref$unstable_system$2 === void 0 ? "opaque" : _ref$unstable_system$2,
      system = _objectWithoutPropertiesLoose(_ref$unstable_system, ["palette", "fill"]),
      options = _objectWithoutPropertiesLoose(_ref, ["unstable_system"]);

  return _objectSpread({
    unstable_system: _objectSpread({
      palette: palette,
      fill: fill
    }, system)
  }, options);
}
function useTooltipProps(_ref2, htmlProps) {
  var unstable_system = _ref2.unstable_system;

  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var _usePaletteBoxProps = useBoxProps({
    unstable_system: unstable_system
  }),
      backgroundColor = _usePaletteBoxProps.style.backgroundColor;

  var fadeBackgroundColor = useFade(backgroundColor || "black", 0.1);
  var tooltip = css(_templateObject(), fadeBackgroundColor, fadeBackgroundColor);
  return _objectSpread({}, htmlProps, {
    className: cx(tooltip, htmlProps.className)
  });
}

export { useTooltipOptions, useTooltipProps };

==> reakit-system-bootstrap-0.6.0.tgz: package/es/Tooltip.js <==
import { c as _objectWithoutPropertiesLoose, a as _objectSpread, b as _taggedTemplateLiteralLoose } from './chunk-119337e1.js';
import { css, cx } from 'emotion';
import { useBoxProps } from 'reakit-system-palette/Box';
import { useFade } from 'reakit-system-palette/utils/fade';

function _templateObject() {
  var data = _taggedTemplateLiteralLoose(["\n    background-color: ", ";\n    font-size: 0.8em;\n    padding: 0.5rem;\n    border-radius: 0.25rem;\n    z-index: 999;\n\n    & > .arrow {\n      background-color: transparent;\n      font-size: 1.25em !important;\n      & .stroke {\n        fill: transparent;\n      }\n      & .fill {\n        fill: ", ";\n      }\n    }\n  "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
function useTooltipOptions(_ref) {
  var _ref$unstable_system = _ref.unstable_system;
  _ref$unstable_system = _ref$unstable_system === void 0 ? {} : _ref$unstable_system;

  var _ref$unstable_system$ = _ref$unstable_system.palette,
      palette = _ref$unstable_system$ === void 0 ? "foreground" : _ref$unstable_system$,
      _ref$unstable_system$2 = _ref$unstable_system.fill,
      fill = _ref$unstable_system$2 === void 0 ? "opaque" : _ref$unstable_system$2,
      system = _objectWithoutPropertiesLoose(_ref$unstable_system, ["palette", "fill"]),
      options = _objectWithoutPropertiesLoose(_ref, ["unstable_system"]);

  return _objectSpread({
    unstable_system: _objectSpread({
      palette: palette,
      fill: fill
    }, system)
  }, options);
}
function useTooltipProps(_ref2, htmlProps) {
  var unstable_system = _ref2.unstable_system;

  if (htmlProps === void 0) {
    htmlProps = {};
  }

  var _usePaletteBoxProps = useBoxProps({
    unstable_system: unstable_system
  }),
      backgroundColor = _usePaletteBoxProps.style.backgroundColor;

  var fadeBackgroundColor = useFade(backgroundColor || "black", 0.1);
  var tooltip = css(_templateObject(), fadeBackgroundColor, fadeBackgroundColor);
  return _objectSpread({}, htmlProps, {
    className: cx(tooltip, htmlProps.className)
  });
}

export { useTooltipOptions, useTooltipProps };
